@@ -149,7 +149,7 @@
         <location filename="mainwindow.ui" line="359"/>
         <location filename="ui_mainwindow.h" line="932"/>
         <source>Rename User Account</source>
-        <translation>Renomear Conta de Usuário</translation>
+        <translation>Renomear a Conta de Usuário</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="371"/>
@@ -213,7 +213,7 @@
         <location filename="ui_mainwindow.h" line="949"/>
         <location filename="ui_mainwindow.h" line="1051"/>
         <source>Modify User Account</source>
-        <translation>Modificar Conta de Usuário</translation>
+        <translation>Modificar a Conta de Usuário</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="576"/>
@@ -247,7 +247,7 @@
         <location filename="mainwindow.ui" line="651"/>
         <location filename="ui_mainwindow.h" line="964"/>
         <source>Mozilla (Iceweasel or Firefox) configs</source>
-        <translation>Configurações Mozilla (Iceweasel ou Firefox)</translation>
+        <translation>Configurações do Mozilla (Iceweasel ou Firefox)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="654"/>
@@ -277,7 +277,7 @@
         <location filename="mainwindow.ui" line="680"/>
         <location filename="ui_mainwindow.h" line="974"/>
         <source>Change Autologin Settings</source>
-        <translation>Alterar Configurações de Autenticação/Acesso (login) Automático</translation>
+        <translation>Alterar as Configurações de Autenticação/Acesso Automático</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="686"/>
@@ -301,7 +301,7 @@
         <location filename="mainwindow.ui" line="735"/>
         <location filename="ui_mainwindow.h" line="979"/>
         <source>Copy Between Desktops</source>
-        <translation>Copiar entre Áreas de Trabalho</translation>
+        <translation>Copiar Entre as Áreas de Trabalho</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="762"/>
@@ -389,7 +389,7 @@
         <location filename="mainwindow.ui" line="938"/>
         <location filename="ui_mainwindow.h" line="1014"/>
         <source>Mozilla (Firefox or Iceweasel) configs</source>
-        <translation>Configurações Mozilla (Firefox ou Iceweasel)</translation>
+        <translation>Configurações do Mozilla (Firefox ou Iceweasel)</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="951"/>
@@ -481,13 +481,13 @@
         <location filename="mainwindow.ui" line="1375"/>
         <location filename="ui_mainwindow.h" line="1059"/>
         <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
-        <translation>O usuário de grupos pertence a (altere os grupos marcando / desmarcando as caixas apropriadas):</translation>
+        <translation>O usuário de grupos pertence a (altere os grupos marcando/desmarcando as caixas apropriadas):</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="1395"/>
         <location filename="ui_mainwindow.h" line="1060"/>
         <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
-        <translation>* Por favor, verifique suas seleções antes de aplicar, atribuindo associações de grupo erradas, poderá quebrar seu sistema. Use a guia Reparar para restaurar as associações originais se você cometeu um erro.</translation>
+        <translation>* Por favor, verifique as suas seleções antes de aplicar, se você atribuir as associações de grupo erradas poderá quebrar seu sistema. Use a guia Reparar para restaurar as associações originais se você cometer algum erro.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="1455"/>
@@ -511,7 +511,7 @@
         <location filename="mainwindow.ui" line="1472"/>
         <location filename="ui_mainwindow.h" line="1068"/>
         <source>Cancel any changes then quit</source>
-        <translation>Cancelar mudanças e sair</translation>
+        <translation>Cancelar as alterações e sair</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="1475"/>
@@ -529,7 +529,7 @@
         <location filename="mainwindow.ui" line="1523"/>
         <location filename="ui_mainwindow.h" line="1074"/>
         <source>Display help </source>
-        <translation>Exibir ajuda</translation>
+        <translation>Exibir a ajuda</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="1526"/>
@@ -584,7 +584,7 @@
     <message>
         <location filename="mainwindow.cpp" line="203"/>
         <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
-        <translation>A configuração de usuário será reparada. Feche todos os outros aplicativos agora. Quando concluído, saia da sessão ou reinicie. Você tem certeza de que deseja reparar agora?</translation>
+        <translation>A configuração de usuário será reparada. Por favor, feche todos os outros aplicativos agora. Quando você concluir, saia da sessão ou reinicie. Você tem certeza de que quer reparar agora?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="225"/>
@@ -594,7 +594,7 @@
     <message>
         <location filename="mainwindow.cpp" line="232"/>
         <source>Mozilla settings were reset.</source>
-        <translation>As definições da Mozilla foram redefinidas.</translation>
+        <translation>As configurações do Mozilla foram redefinidas.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="237"/>
@@ -620,12 +620,12 @@
     <message>
         <location filename="mainwindow.cpp" line="265"/>
         <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
-        <translation>Antes de copiar, feche todas os outros aplicativos. Certifique-se de que o destino de &apos;copiar para&apos; é suficientemente grande para receber todos os os arquivos que você está copiando. Copiar entre áreas de trabalho pode sobrescrever ou apagar seus arquivos ou preferências na área de trabalho de destino. Você tem certeza de que deseja continuar?</translation>
+        <translation>Antes de copiar, feche todas os outros aplicativos. Certifique-se de que o destino de &apos;copiar para&apos; é suficientemente grande para receber todos os os arquivos que você está copiando. Copiar entre as áreas de trabalho pode sobrescrever ou apagar seus arquivos ou preferências na área de trabalho de destino. Você tem certeza de que quer continuar?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="290"/>
         <source>Synchronizing desktop...</source>
-        <translation>Sincronizando área de trabalho ...</translation>
+        <translation>Sincronizando a área de trabalho ...</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="292"/>
@@ -644,9 +644,11 @@
         <source>The user name needs to be lower case and it
 cannot contain special characters or spaces.
 Please choose another name before proceeding.</source>
-        <translation>O nome de usuário tem que estar em minúsculas
-e não pode conter caracteres especiais ou espaços.
-Escolha outro nome de usuário antes de continuar.</translation>
+        <translation>O nome de usuário tem que estar em letras 
+minúsculas e não pode conter caracteres 
+especiais ou espaços. 
+Por favor, escolha outro nome de usuário 
+antes de continuar.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="326"/>
@@ -703,16 +705,18 @@ Escolha outro nome de usuário antes de continuar.</translation>
     <message>
         <location filename="mainwindow.cpp" line="425"/>
         <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation>O nome de grupo tem que ter pelo menos 2 caracteres. Escolha um nome mais longo antes de continuar.</translation>
+        <translation>O nome de grupo tem que ter pelo menos 2 caracteres. Por favor, escolha um nome mais longo antes de continuar.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="429"/>
         <source>The group name needs to be lower case and it 
 cannot contain special characters or spaces.
 Please choose another name before proceeding.</source>
-        <translation>O nome de grupo tem que estar em minúsculas
-e não pode conter caracteres especiais ou espaços.
-Escolha outro nome antes de continuar.</translation>
+        <translation>O nome de grupo tem que estar em letras 
+minúsculas e não pode conter caracteres 
+especiais ou espaços.
+Por favor, escolha outro nome antes de 
+continuar.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="438"/>
@@ -732,7 +736,7 @@ Escolha outro nome antes de continuar.</translation>
     <message>
         <location filename="mainwindow.cpp" line="451"/>
         <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
-        <translation>Esta ação não pode ser desfeita. Você tem certeza de que pretende apagar o grupo %1?</translation>
+        <translation>Esta ação não poderá ser desfeita. Você tem certeza de que pretende apagar o grupo %1?</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="458"/>
@@ -772,7 +776,7 @@ Escolha outro nome antes de continuar.</translation>
     <message>
         <location filename="mainwindow.cpp" line="529"/>
         <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
-        <translation>Falha ao renomear o usuário. Certifique-se de que o usuário não está em sessão; pode ser necessário reiniciar.</translation>
+        <translation>Falha ao renomear o usuário. Por favor, certifique-se de que o usuário não esteja acessando a sessão; pode ser necessário reiniciar.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="543"/>
@@ -783,23 +787,23 @@ Escolha outro nome antes de continuar.</translation>
         <location filename="mainwindow.cpp" line="556"/>
         <location filename="mainwindow.cpp" line="585"/>
         <source>Synchronizing desktop...ok</source>
-        <translation>Sincronizando área de trabalho... concluído.</translation>
+        <translation>Sincronizando a área de trabalho... concluído.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="558"/>
         <location filename="mainwindow.cpp" line="587"/>
         <source>Copying desktop...ok</source>
-        <translation>Copiando área de trabalho ... concluído.</translation>
+        <translation>Copiando a área de trabalho ... concluído.</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="591"/>
         <source>Synchronizing desktop...failed</source>
-        <translation>Sincronizando área de trabalho ... falhou</translation>
+        <translation>Sincronizando a área de trabalho ... falhou</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="593"/>
         <source>Copying desktop...failed</source>
-        <translation>Copiando área de trabalho... falhou </translation>
+        <translation>Copiando a área de trabalho... falhou </translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="611"/>
